@@ -15,7 +15,7 @@ from collections import deque
 from functools import wraps
 
 __author__ = u'Stefan Kögl <stefan@skoegl.net>'
-__version__ = '0.8'
+__version__ = '0.9'
 __website__ = 'https://github.com/stefankoegl/kdtree'
 __license__ = 'ISC license'
 
@@ -419,18 +419,18 @@ class KDNode(Node):
         get_dist = lambda n: n.dist(point)
 
         # the nodes do not keep a reference to their parents
-        parents = {current: None}
+        parents = {id(current): None}
 
         # go down the tree as we would for inserting
         while current:
             if point[current.axis] < current.data[current.axis]:
                 # left side
-                parents[current.left] = current
+                parents[id(current.left)] = current
                 prev = current
                 current = current.left
             else:
                 # right side
-                parents[current.right] = current
+                parents[id(current.right)] = current
                 prev = current
                 current = current.right
 
@@ -444,7 +444,7 @@ class KDNode(Node):
         while current:
             # search node and update results
             current._search_node(point, k, results, examined, get_dist)
-            current = parents[current]
+            current = parents[id(current)]
 
         return sorted(results, key=get_dist)
 
